@@ -51,7 +51,7 @@
 #' }
 #' 
 #' @examples 
-#' \donttest{
+#' \dontrun{
 #' # Note: 
 #' # - Require AWS Account to run below example.
 #' # - Different connection methods can be used please see `noctua::dbConnect` documnentation
@@ -242,6 +242,13 @@ get_session_token <- function(profile_name = NULL,
             is.numeric(duration_seconds),
             is.logical(set_env))
   
+  # get lower level paws methods
+  get_region <- pkg_method("get_region", "paws.common")
+  get_profile_name <- pkg_method("get_profile_name", "paws.common")
+  
+  region_name <- region_name %||% get_region(profile_name)
+  profile_name <-  profile_name %||% get_profile_name(profile_name)
+  
   config <- cred_set(NULL, NULL, NULL, profile_name, region_name)
   
   STS <- paws::sts(config)
@@ -300,6 +307,13 @@ assume_role <- function(profile_name = NULL,
             is.numeric(duration_seconds),
             is.logical(set_env))
   
+  # get lower level paws methods
+  get_region <- pkg_method("get_region", "paws.common")
+  get_profile_name <- pkg_method("get_profile_name", "paws.common")
+  
+  region_name <- region_name %||% get_region(profile_name)
+  profile_name <-  profile_name %||% get_profile_name(profile_name)
+  
   config <- cred_set(NULL, NULL, NULL, profile_name, region_name)
   
   STS <- paws::sts(config)
@@ -309,4 +323,4 @@ assume_role <- function(profile_name = NULL,
                                         DurationSeconds = as.integer(duration_seconds))})
   if(set_env) {set_aws_env(response)}
   response$Credentials
-}
\ No newline at end of file
+}
