@@ -23,11 +23,4 @@ test_that("Check noctua s3 dplyr compute method",{
   
   expect_equal(result1, TRUE)
   expect_equal(result2, TRUE)
-  
-  # clean up system environmental variables
-  Sys.unsetenv("AWS_ACCESS_KEY_ID")
-  Sys.unsetenv("AWS_SECRET_ACCESS_KEY")
-  Sys.unsetenv("AWS_SESSION_TOKEN")
-  Sys.unsetenv("AWS_PROFILE")
-  Sys.unsetenv("AWS_REGION")
 })
