@@ -79,7 +79,7 @@ test_that("Check RAthena s3 dplyr sql_translate_env method",{
   expect_equal(t3 ,sql("CAST('1.2' AS DOUBLE)"))
   expect_equal(t4 ,sql("CAST(1.2 AS INTEGER)"))
   expect_equal(t5 ,sql("CAST(1.2 AS BIGINT)"))
-  expect_equal(t6 ,sql("CAST(DATE '2019-01-01' AS DATE)"))
+  expect_equal(t6 ,sql("CAST(date '2019-01-01' AS DATE)"))
   expect_equal(t7 ,sql("CAST('true' AS BOOLEAN)"))
   expect_equal(t8 ,sql("CAST(10.0 AS VARBINARY)"))
   expect_equal(t9 ,sql("LOWER('HELLO')"))
@@ -92,11 +92,11 @@ test_that("Check RAthena s3 dplyr sql_translate_env method",{
   expect_equal(t16 ,sql("('hi'||' '||'bye')"))
   expect_equal(t17 ,sql("('hi'||'-'||'bye')"))
   expect_equal(t18 ,sql("CONCAT('hi', 'bye')"))
-  expect_equal(t19, sql("DATE '2020-01-01'"))
-  expect_equal(t20, sql("DATE '2020-01-01'"))
+  expect_equal(t19, sql("date '2020-01-01'"))
+  expect_equal(t20, sql("date '2020-01-01'"))
   expect_equal(t21, sql("'2020-13-01'"))
-  expect_equal(t22, sql("CAST(DATE '2020-01-01' AS VARCHAR)"))
-  expect_equal(t23, sql("(DATE '2020-01-01', DATE '2020-01-02')"))
+  expect_equal(t22, sql("CAST(date '2020-01-01' AS VARCHAR)"))
+  expect_equal(t23, sql("(date '2020-01-01', date '2020-01-02')"))
   expect_equal(t24, sql("('2020-01-01', '2020-13-02')"))
   expect_equal(t25, sql("CAST(1.0 AS STRING)"))
   expect_equal(t26, sql("\"iris\"['sepal_length']"))
