@@ -27,11 +27,4 @@ test_that("Check a table exist and remove table",{
   expect_equal(table_exist1, FALSE)
   expect_equal(table_exist2, TRUE)
   expect_equal(table_exist3, FALSE)
-  
-  # clean up system environmental variables
-  Sys.unsetenv("AWS_ACCESS_KEY_ID")
-  Sys.unsetenv("AWS_SECRET_ACCESS_KEY")
-  Sys.unsetenv("AWS_SESSION_TOKEN")
-  Sys.unsetenv("AWS_PROFILE")
-  Sys.unsetenv("AWS_REGION")
 })
